============
CLI Guide
============


    $ mfe_saw -h

..    
    usage: mfe_saw [-h] [-a] [-s [term]] [-v] [--version]

    McAfee SIEM API Wrapper

    optional arguments:
      -h, --help            show this help message and exit
      -a, --add             Scan <dsdir> for new datasource files
      -s [term], --search [term]
                            Search for datasource name, hostname, or IP.May
                            require quotes around the name if thereare spaces.
      -v                    Prints the software release version for the ESM.
      --version             mfe_saw version